@@ -222,6 +222,8 @@ const char* tests[] = {
   "SET search_path TO my_schema, public",
   "SET LOCAL search_path TO my_schema, public",
   "SET \"user\" TO 4",
+  "SET TIME ZONE interval '+00:00' hour to minute",
+  "SET timezone TO -7",
   "VACUUM",
   "VACUUM t",
   "VACUUM (FULL) t",
@@ -387,6 +389,7 @@ const char* tests[] = {
   "ALTER TABLE ALL IN TABLESPACE foo OWNED BY bar, quux SET TABLESPACE fred NOWAIT",
   "MERGE INTO measurement m USING new_measurement nm ON m.city_id = nm.city_id AND m.logdate = nm.logdate WHEN MATCHED AND nm.peaktemp IS NULL THEN DELETE WHEN MATCHED THEN UPDATE SET peaktemp = GREATEST(m.peaktemp, nm.peaktemp), unitsales = m.unitsales + COALESCE(nm.unitsales, 0) WHEN NOT MATCHED THEN INSERT (city_id, logdate, peaktemp, unitsales) VALUES (city_id, logdate, peaktemp, unitsales)",
   "COPY vistest FROM STDIN FREEZE CSV",
+  "CREATE INDEX \"foo.index\" ON foo USING btree (bar)",
 };
 
 size_t testsLength = __LINE__ - 4;
